package com.ekexiu.project.msconsole.system.service;

import com.ekexiu.project.msconsole.system.vo.UploadFile;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.operate.Post;
import org.jfw.apt.web.annotation.param.Upload;
import org.jfw.util.io.IoUtil;
import org.jfw.util.web.fileupload.Item;
import org.jfw.util.web.fileupload.UploadItemIterator;

import javax.imageio.ImageIO;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.concurrent.atomic.AtomicInteger;

@Path
public class CommonUtilService {

    public String rootPath;

    public static final String JPG = "jpg";

    private static final AtomicInteger HOSPITAL_FN_IND = new AtomicInteger(1);
    private File hospitalPath;

    private static final AtomicInteger DOCTOR_FN_IDX = new AtomicInteger(1);
    private File doctorPath;

    private static final AtomicInteger INSTRUMENT_FN_IDX = new AtomicInteger(1);
    private File instrumentPath;

    private int headMaxHeight = Integer.MAX_VALUE;


    public String getRootPath() {
        return rootPath;
    }

    public void setRootPath(String rootPath) {
        this.rootPath = rootPath;
    }

    public File getDoctorPath() {
        return doctorPath;
    }

    public void setDoctorPath(File doctorPath) {
        this.doctorPath = doctorPath;
    }

    public File getHospitalPath() {
        return hospitalPath;
    }

    public void setHospitalPath(File hospitalPath) {
        this.hospitalPath = hospitalPath;
    }

    public File getInstrumentPath() {
        return instrumentPath;
    }

    public void setInstrumentPath(File instrumentPath) {
        this.instrumentPath = instrumentPath;
    }

    public int getHeadMaxHeight() {
        return headMaxHeight;
    }

    public void setHeadMaxHeight(int headMaxHeight) {
        this.headMaxHeight = headMaxHeight;
    }

    private String normalizeFileName(String fn) {
        int index = fn.indexOf('\\');
        if (index >= 0) {
            fn = fn.substring(fn.lastIndexOf('\\') + 1);
        }
        index = fn.indexOf('/');
        if (index >= 0) {
            fn = fn.substring(fn.lastIndexOf('/') + 1);
        }
        if (fn.length() == 0)
            throw new RuntimeException("invalid filename in Multipart/data request");
        return fn;
    }

    private UploadFile buildTargetFile(File parentPath, AtomicInteger FN_IDX, String ext) {
        StringBuilder sb = new StringBuilder();
        sb.append("/").append(System.currentTimeMillis() / (1000 * 60 * 60 * 24));
        File path = new File(parentPath, sb.toString());
        if (!path.exists()) {
            synchronized (this) {
                if (!path.mkdirs())
                    throw new RuntimeException("mkdir error[" + path + "]");
                FN_IDX.set(1);
            }
        }
        File file;
        do {
            String fn = FN_IDX.toString();
            if (ext.isEmpty()) {
                file = new File(path, fn);
            } else {
                file = new File(path, fn + "." + ext);
            }
            FN_IDX.incrementAndGet();
        } while (file.exists());
        sb.append("/").append(file.getName());
        UploadFile uf = new UploadFile();
        uf.setFn(file);
        uf.setUri(sb.toString());
        return uf;
    }

    private void saveHeadPhoto(InputStream in, UploadFile file) throws IOException {
        byte[] buf = new byte[8092];
        int w, h, sx1, sx2, sy1, sy2;
        int len;
        ByteArrayOutputStream of = new ByteArrayOutputStream();
        while ((len = in.read(buf)) >= 0) {
            if (len > 0) {
                of.write(buf, 0, len);
            }
        }
        BufferedImage im = ImageIO.read(in);
        if (im == null) {
            throw new IOException("unsupported image type");
        }
        sx1 = 0;
        sy1 = 0;
        sx2 = w = im.getWidth();
        sy2 = h = im.getHeight();
        if (w > h) {
            sx1 = (w - h) / 2;
            sx2 = sx1 + h;
            w = h;
        } else if (w < h) {
            sy1 = (h - w) / 2;
            sy2 = sy1 + w;
            h = w;
        }
        if (h > this.headMaxHeight) {
            w = h = this.headMaxHeight;
        }
        BufferedImage newBufferedImage = new BufferedImage(w, h, BufferedImage.TYPE_INT_RGB);
        newBufferedImage.createGraphics().drawImage(im, 0, 0, w, h, sx1, sy1, sx2, sy2, Color.WHITE, null);
        OutputStream fos = new FileOutputStream(file.getFn());
        try {
            ImageIO.write(newBufferedImage, JPG, fos);
            fos.flush();
            file.setSize(file.getFn().length());
        } finally {
            IoUtil.close(fos);
        }
    }

    @Post
    @Path("/hospitalPath/logo")
    public UploadFile logoUpload(@Upload UploadItemIterator it) throws IOException {
        UploadFile uf = null;
        try {
            while (it.hasNext()) {
                Item item = it.next();
                if (!item.isFormField()) {
                    String name = normalizeFileName(item.getName());
                    int index = name.lastIndexOf('.');
                    String ext = index >= 0 ? name.substring(index + 1) : "";
                    ext = ext.trim();
                    uf = buildTargetFile(this.hospitalPath,HOSPITAL_FN_IND , ext);
                    uf.setName(name);
                    InputStream in = item.getInputStream();
                    try {
                        OutputStream fos = new FileOutputStream(uf.getFn());
                        try {
                            IoUtil.copy(in, fos, false, false);
                            fos.flush();
                        } finally {
                            fos.close();
                        }
                        uf.setUri(rootPath + "/data/hospital/logo" + uf.getUri());
                        return uf;
                    } finally {
                        in.close();
                    }
                }
            }
        } finally {
            if (it != null)
                it.clean();
        }
        return uf;
    }

    @Post
    @Path("/doctor/image")
    public UploadFile articleImageUpload(@Upload UploadItemIterator it) throws IOException {
        UploadFile uf = null;
        try {
            while (it.hasNext()) {
                Item item = it.next();
                if (!item.isFormField()) {
                    String name = normalizeFileName(item.getName());
                    int index = name.lastIndexOf('.');
                    String ext = index >= 0 ? name.substring(index + 1) : "";
                    ext = ext.trim();
                    uf = buildTargetFile(this.doctorPath, DOCTOR_FN_IDX, ext);
                    uf.setName(name);
                    InputStream in = item.getInputStream();
                    try {
                        OutputStream fos = new FileOutputStream(uf.getFn());
                        try {
                            IoUtil.copy(in, fos, false, false);
                            fos.flush();
                        } finally {
                            fos.close();
                        }
                        uf.setUri(rootPath + "/data/doctor/logo" + uf.getUri());
                        return uf;
                    } finally {
                        in.close();
                    }
                }
            }
        } finally {
            if (it != null)
                it.clean();
        }
        return uf;
    }

    @Post
    @Path("/instrument/logo")
    public UploadFile productImageUpload(@Upload UploadItemIterator it) throws IOException {
        UploadFile uf = null;
        try {
            while (it.hasNext()) {
                Item item = it.next();
                if (!item.isFormField()) {
                    String name = normalizeFileName(item.getName());
                    int index = name.lastIndexOf('.');
                    String ext = index >= 0 ? name.substring(index + 1) : "";
                    ext = ext.trim();
                    uf = buildTargetFile(this.instrumentPath, INSTRUMENT_FN_IDX, ext);
                    uf.setName(name);
                    InputStream in = item.getInputStream();
                    try {
                        OutputStream fos = new FileOutputStream(uf.getFn());
                        try {
                            IoUtil.copy(in, fos, false, false);
                            fos.flush();
                        } finally {
                            fos.close();
                        }
                        uf.setUri(rootPath + "/data/instrument/logo" + uf.getUri());
                        return uf;
                    } finally {
                        in.close();
                    }
                }
            }
        } finally {
            if (it != null)
                it.clean();
        }
        return uf;
    }


}
