package com.ekexiu.project.msconsole.system.service;

import com.ekexiu.project.msconsole.system.dao.HospitalDao;
import com.ekexiu.project.msconsole.system.po.Hospital;
import com.ekexiu.project.msconsole.system.vo.SessionUser;
import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.web.annotation.LoginUser;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.method.InvalidSession;
import org.jfw.apt.web.annotation.method.SetSession;
import org.jfw.apt.web.annotation.operate.Get;
import org.jfw.apt.web.annotation.operate.Post;
import org.jfw.apt.web.annotation.param.JdbcConn;
import org.jfw.util.PageQueryResult;
import org.jfw.util.StringUtil;
import org.jfw.util.exception.JfwBaseException;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by TT on 2019/5/30.
 */
@Path("/sys")
public class SysService {

    public static final String DEFAULT_PW_STR = StringUtil.md5("123456");

    @Autowrie
    private HospitalDao hospitalDao;

    public HospitalDao getHospitalDao() {
        return hospitalDao;
    }

    public void setHospitalDao(HospitalDao hospitalDao) {
        this.hospitalDao = hospitalDao;
    }

    public static String getDefaultPwStr() {
        return DEFAULT_PW_STR;
    }

    @SetSession("/JFW_SESSION_LOGIN_USER=result")
    @Path("/login")
    @Post
    public SessionUser login(@JdbcConn Connection con, String account, String pw) throws SQLException, JfwBaseException {
        Hospital hospital = hospitalDao.login(con, account, pw);
        if (hospital != null) {
            if (!hospital.isActive()) {
                throw new JfwBaseException(-60005, "hospital is disabled");
            }
            return makeSessionUser(hospital);
        }
        return null;
    }

    @InvalidSession
    @Path("/logout")
    @Get
    public void logout() {
    }

    @Path("/user")
    @Get
    public SessionUser get(@LoginUser SessionUser user) {
        return user;
    }

    @Path("/insert")
    @Post
    public String insert(@JdbcConn(true) Connection con, @LoginUser SessionUser sessionUser, Hospital hospital) throws SQLException {
        String id = StringUtil.buildUUID();
        String account;
        for (; ; ) {
            double random = ((Math.random() * 9 + 1) * 100000);
            account = Double.toString(random);
            Hospital hospital1 = hospitalDao.queryByAccount(con, account, id);
            if (hospital1 == null) {
                break;
            }
        }
        hospital.setId(id);
        hospital.setAccount(account);
        hospital.setActive(true);
        hospital.setPasswd(DEFAULT_PW_STR);
        hospital.setCreator(sessionUser.getId());
        hospital.setModifier(sessionUser.getId());
        hospitalDao.insert(con, hospital);
        return id;
    }

    @Path("/qo")
    @Get
    public SessionUser query(@JdbcConn Connection con, String id) throws SQLException {
        return makeSessionUser(hospitalDao.query(con, id));
    }

    @Path("/update")
    @Post
    public void update(@JdbcConn(true) Connection con, @LoginUser SessionUser sessionUser, Hospital hospital) throws SQLException {
        hospital.setModifier(sessionUser.getId());
        hospitalDao.update(con, hospital);
    }

    @Path("/ban")
    @Get
    public void ban(@JdbcConn(true) Connection con, @LoginUser SessionUser sessionUser, String id) throws SQLException {
        hospitalDao.ban(con, id, sessionUser.getId());
    }

    @Post
    @Path("/resetPw")
    @LoginUser
    public void resetPw(@JdbcConn(true) Connection con,String id)throws SQLException {
        this.hospitalDao.changePw(con, DEFAULT_PW_STR, id);
    }

    @Path("/pq")
    @Get
    public PageQueryResult<SessionUser> pageQuery(@JdbcConn Connection con, @Nullable Boolean active,@Nullable String level,@Nullable String subLevel,@Nullable String type,@Nullable String name,int pageSize,int pageNo)throws SQLException {
        PageQueryResult<Hospital> pageQueryResult = hospitalDao.pageQuery(con, active, level, subLevel, type, name == null ? null : "%" + name + "%", pageSize, pageNo);
        List<Hospital> hospitals = pageQueryResult.getData();
        List<SessionUser> sessionUsers = new ArrayList<>();
        if (!hospitals.isEmpty()) {
            for (Hospital hospital : hospitals) {
                sessionUsers.add(makeSessionUser(hospital));
            }
            PageQueryResult<SessionUser> ret = new PageQueryResult<>();
            ret.setPageNo(pageQueryResult.getPageNo());
            ret.setPageSize(pageQueryResult.getPageSize());
            ret.setTotal(pageQueryResult.getTotal());
            ret.setData(sessionUsers);
            return ret;
        }
        return null;
    }




    private static SessionUser makeSessionUser(Hospital hospital) {
        SessionUser sessionUser = new SessionUser();
        sessionUser.setAccount(hospital.getAccount());
        sessionUser.setName(hospital.getName());
        sessionUser.setLevel(hospital.getLevel());
        sessionUser.setSubLevel(hospital.getSubLevel());
        sessionUser.setId(hospital.getId());
        sessionUser.setType(hospital.getType());
        sessionUser.setPhone(hospital.getPhone());
        sessionUser.setLocation(hospital.getLocation());
        sessionUser.setAddr(hospital.getAddr());
        sessionUser.setDesc(hospital.getDescp());
        sessionUser.setImage(hospital.getImage());
        sessionUser.setActive(hospital.isActive());
        return sessionUser;
    }
}
