CREATE TABLE HOSPITAL (
  ID CHAR(32) NOT NULL,
  PASSWD TEXT NOT NULL,
  ACCOUNT TEXT NOT NULL,
  NAME TEXT NOT NULL,
  LEVEL CHAR(1) NOT NULL,
  SUB_LEVEL CHAR(1) NOT NULL,
  TYPE CHAR(1) NOT NULL,
  PHONE TEXT,
  LOCATION TEXT,
  ADDR VARCHAR(255),
  DESCP TEXT,
  IMAGE TEXT,
  ACTIVE CHAR(1) NOT NULL,
  CREATE_TIME CHAR(14) NOT NULL,
  MODIFY_TIME CHAR(14) NOT NULL,
  CREATOR CHAR(32) NOT NULL,
  MODIFIER CHAR(32) NOT NULL);
ALTER TABLE HOSPITAL ADD PRIMARY KEY (ID);
ALTER TABLE HOSPITAL ADD UNIQUE (ACCOUNT);
COMMENT ON TABLE HOSPITAL IS '医院登录表';
COMMENT ON COLUMN HOSPITAL.ID IS '医院ID';
COMMENT ON COLUMN HOSPITAL.PASSWD IS '密码(MD5)';
COMMENT ON COLUMN HOSPITAL.ACCOUNT IS '医院帐号';
COMMENT ON COLUMN HOSPITAL.NAME IS '医院名称';
COMMENT ON COLUMN HOSPITAL.LEVEL IS '医院级别';
COMMENT ON COLUMN HOSPITAL.SUB_LEVEL IS '医院子级别';
COMMENT ON COLUMN HOSPITAL.TYPE IS '医院类型';
COMMENT ON COLUMN HOSPITAL.PHONE IS '电话';
COMMENT ON COLUMN HOSPITAL.LOCATION IS '医院详细地址';
COMMENT ON COLUMN HOSPITAL.ADDR IS '医院所在城市编码';
COMMENT ON COLUMN HOSPITAL.DESCP IS '医院简介';
COMMENT ON COLUMN HOSPITAL.IMAGE IS '医院图片';
COMMENT ON COLUMN HOSPITAL.ACTIVE IS '是否可用';
COMMENT ON COLUMN HOSPITAL.CREATE_TIME IS '创建时间（YYYYMMDDHH24MISS）不可修改';
COMMENT ON COLUMN HOSPITAL.MODIFY_TIME IS '最后修改时间（YYYYMMDDHH24MISS）,初始值:20000101010101';
COMMENT ON COLUMN HOSPITAL.CREATOR IS '创建人ID';
COMMENT ON COLUMN HOSPITAL.MODIFIER IS '最后修改人ID';
CREATE TABLE SYS_DICT (
  CODE TEXT NOT NULL,
  BCODE TEXT,
  DICT_CODE TEXT NOT NULL,
  CAPTION TEXT NOT NULL,
  FULL_CAPTION TEXT,
  SHORT_CUT TEXT,
  REMARK TEXT,
  READONLY CHAR(1) NOT NULL,
  ACTIVE CHAR(1) NOT NULL);
ALTER TABLE SYS_DICT ADD PRIMARY KEY (DICT_CODE,CODE);
COMMENT ON TABLE SYS_DICT IS '数据字典表';
COMMENT ON COLUMN SYS_DICT.CODE IS '字典项编码';
COMMENT ON COLUMN SYS_DICT.BCODE IS '字典项编码(业务编码)';
COMMENT ON COLUMN SYS_DICT.DICT_CODE IS '字典编码';
COMMENT ON COLUMN SYS_DICT.CAPTION IS '字典项显示';
COMMENT ON COLUMN SYS_DICT.FULL_CAPTION IS '字典项显示(全)';
COMMENT ON COLUMN SYS_DICT.SHORT_CUT IS '助记码';
COMMENT ON COLUMN SYS_DICT.REMARK IS '备注';
COMMENT ON COLUMN SYS_DICT.READONLY IS '是否只读';
COMMENT ON COLUMN SYS_DICT.ACTIVE IS '是否有效';
CREATE TABLE INSTRUMENT (
  ID CHAR(32) NOT NULL,
  NAME TEXT NOT NULL,
  STATUS CHAR(1) NOT NULL,
  DEPARTMENT CHAR(32),
  HOSPITAL CHAR(32) NOT NULL,
  SPEC TEXT,
  APPLICATION TEXT,
  DESCP TEXT,
  IMAGE TEXT,
  ACTIVE CHAR(1) NOT NULL,
  CREATE_TIME CHAR(14) NOT NULL,
  MODIFY_TIME CHAR(14) NOT NULL,
  CREATOR CHAR(32) NOT NULL,
  MODIFIER CHAR(32) NOT NULL);
ALTER TABLE INSTRUMENT ADD PRIMARY KEY (ID);
COMMENT ON TABLE INSTRUMENT IS '器械表';
COMMENT ON COLUMN INSTRUMENT.ID IS '器械ID';
COMMENT ON COLUMN INSTRUMENT.NAME IS '器械名称';
COMMENT ON COLUMN INSTRUMENT.STATUS IS '器械状态';
COMMENT ON COLUMN INSTRUMENT.DEPARTMENT IS '所属科室';
COMMENT ON COLUMN INSTRUMENT.HOSPITAL IS '所属医院';
COMMENT ON COLUMN INSTRUMENT.SPEC IS '厂商型号';
COMMENT ON COLUMN INSTRUMENT.APPLICATION IS '功能用途';
COMMENT ON COLUMN INSTRUMENT.DESCP IS '器械简介';
COMMENT ON COLUMN INSTRUMENT.IMAGE IS '器械图片';
COMMENT ON COLUMN INSTRUMENT.ACTIVE IS '是否可用';
COMMENT ON COLUMN INSTRUMENT.CREATE_TIME IS '创建时间（YYYYMMDDHH24MISS）不可修改';
COMMENT ON COLUMN INSTRUMENT.MODIFY_TIME IS '最后修改时间（YYYYMMDDHH24MISS）,初始值:20000101010101';
COMMENT ON COLUMN INSTRUMENT.CREATOR IS '创建人ID';
COMMENT ON COLUMN INSTRUMENT.MODIFIER IS '最后修改人ID';
CREATE TABLE DOCTOR (
  ID CHAR(32) NOT NULL,
  HOSPITAL CHAR(32) NOT NULL,
  DEPARTMENT CHAR(32),
  ACCOUNT TEXT NOT NULL,
  NAME TEXT NOT NULL,
  CLINICAL_TITLE TEXT,
  TEACH_TITLE TEXT,
  POSITION TEXT,
  DIRECTION TEXT,
  IMAGE VARCHAR(255),
  DESCP TEXT,
  ACTIVE CHAR(1) NOT NULL,
  PASSWD TEXT NOT NULL,
  CREATE_TIME CHAR(14) NOT NULL,
  MODIFY_TIME CHAR(14) NOT NULL,
  CREATOR CHAR(32) NOT NULL,
  MODIFIER CHAR(32) NOT NULL);
ALTER TABLE DOCTOR ADD PRIMARY KEY (ID);
ALTER TABLE DOCTOR ADD UNIQUE (ACCOUNT);
COMMENT ON TABLE DOCTOR IS '医生';
COMMENT ON COLUMN DOCTOR.ID IS '医生ID';
COMMENT ON COLUMN DOCTOR.HOSPITAL IS '医院ID';
COMMENT ON COLUMN DOCTOR.DEPARTMENT IS '医院ID';
COMMENT ON COLUMN DOCTOR.ACCOUNT IS '帐号';
COMMENT ON COLUMN DOCTOR.NAME IS '医生姓名';
COMMENT ON COLUMN DOCTOR.CLINICAL_TITLE IS '临床职称';
COMMENT ON COLUMN DOCTOR.TEACH_TITLE IS '教学职称';
COMMENT ON COLUMN DOCTOR.POSITION IS '行政职务';
COMMENT ON COLUMN DOCTOR.DIRECTION IS '擅长方向';
COMMENT ON COLUMN DOCTOR.IMAGE IS '图片';
COMMENT ON COLUMN DOCTOR.DESCP IS '个人简介';
COMMENT ON COLUMN DOCTOR.ACTIVE IS '是否可用';
COMMENT ON COLUMN DOCTOR.PASSWD IS '密码(MD5)';
COMMENT ON COLUMN DOCTOR.CREATE_TIME IS '创建时间（YYYYMMDDHH24MISS）不可修改';
COMMENT ON COLUMN DOCTOR.MODIFY_TIME IS '最后修改时间（YYYYMMDDHH24MISS）,初始值:20000101010101';
COMMENT ON COLUMN DOCTOR.CREATOR IS '创建人ID';
COMMENT ON COLUMN DOCTOR.MODIFIER IS '最后修改人ID';
CREATE TABLE DEPARTMENT (
  ID CHAR(32) NOT NULL,
  HOSPITAL CHAR(32) NOT NULL,
  NAME TEXT NOT NULL,
  TYPE CHAR(1) NOT NULL,
  PHONE TEXT,
  LOCATION TEXT,
  DESCP TEXT,
  ACTIVE CHAR(1) NOT NULL,
  CREATE_TIME CHAR(14) NOT NULL,
  MODIFY_TIME CHAR(14) NOT NULL,
  CREATOR CHAR(32) NOT NULL,
  MODIFIER CHAR(32) NOT NULL);
ALTER TABLE DEPARTMENT ADD PRIMARY KEY (ID);
COMMENT ON TABLE DEPARTMENT IS '科室';
COMMENT ON COLUMN DEPARTMENT.ID IS '科室ID';
COMMENT ON COLUMN DEPARTMENT.HOSPITAL IS '所属医院ID';
COMMENT ON COLUMN DEPARTMENT.NAME IS '科室名称';
COMMENT ON COLUMN DEPARTMENT.TYPE IS '科室ID';
COMMENT ON COLUMN DEPARTMENT.PHONE IS '科室电话';
COMMENT ON COLUMN DEPARTMENT.LOCATION IS '科室地址';
COMMENT ON COLUMN DEPARTMENT.DESCP IS '科室简介';
COMMENT ON COLUMN DEPARTMENT.ACTIVE IS '是否可用';
COMMENT ON COLUMN DEPARTMENT.CREATE_TIME IS '创建时间（YYYYMMDDHH24MISS）不可修改';
COMMENT ON COLUMN DEPARTMENT.MODIFY_TIME IS '最后修改时间（YYYYMMDDHH24MISS）,初始值:20000101010101';
COMMENT ON COLUMN DEPARTMENT.CREATOR IS '创建人ID';
COMMENT ON COLUMN DEPARTMENT.MODIFIER IS '最后修改人ID';
